Struct ssh2::Error[][src]

pub struct Error { /* fields omitted */ }

Representation of an error that can occur within libssh2

Methods

impl Error
[src]

Generate the last error that occurred for a Session.

Returns None if there was no last error.

Create a new error for the given code and message

Generate an error that represents EOF

Generate an error for unknown failure

Construct an error from an error code from libssh2

Get the message corresponding to this error

Return the code for this error