Struct ssh2::FileStat [−][src]
pub struct FileStat {
pub size: Option<u64>,
pub uid: Option<u32>,
pub gid: Option<u32>,
pub perm: Option<u32>,
pub atime: Option<u64>,
pub mtime: Option<u64>,
}Metadata information about a remote file.
Fields are not necessarily all provided
Fields
size: Option<u64>
File size, in bytes of the file.
uid: Option<u32>
Owner ID of the file
gid: Option<u32>
Owning group of the file
perm: Option<u32>
Permissions (mode) of the file
atime: Option<u64>
Last access time of the file
mtime: Option<u64>
Last modification time of the file
Methods
impl FileStat[src]
impl FileStatpub fn file_type(&self) -> FileType[src]
pub fn file_type(&self) -> FileTypeReturns the file type for this filestat.
pub fn is_dir(&self) -> bool[src]
pub fn is_dir(&self) -> boolReturns whether this metadata is for a directory.
pub fn is_file(&self) -> bool[src]
pub fn is_file(&self) -> boolReturns whether this metadata is for a regular file.
pub fn from_raw(raw: &LIBSSH2_SFTP_ATTRIBUTES) -> FileStat[src]
pub fn from_raw(raw: &LIBSSH2_SFTP_ATTRIBUTES) -> FileStatCreates a new instance of a stat from a raw instance.
pub fn raw(&self) -> LIBSSH2_SFTP_ATTRIBUTES[src]
pub fn raw(&self) -> LIBSSH2_SFTP_ATTRIBUTESConvert this stat structure to its raw representation.