Struct ssh2::FileType[][src]

pub struct FileType { /* fields omitted */ }

An structure representing a type of file.

Methods

impl FileType
[src]

Test whether this file type represents a directory.

Test whether this file type represents a regular file.

Test whether this file type represents a symbolic link.