Struct ssh2::Host[][src]

pub struct Host<'kh> { /* fields omitted */ }

Structure representing a known host as part of a KnownHosts structure.

Methods

impl<'kh> Host<'kh>
[src]

This is None if no plain text host name exists.

Returns the key in base64/printable format