Struct ssh2::OpenFlags [−]
pub struct OpenFlags { /* fields omitted */ }Options that can be used to configure how a file is opened
Methods
impl OpenFlags
impl OpenFlagspub fn empty() -> OpenFlags
pub fn empty() -> OpenFlagsReturns an empty set of flags.
pub fn all() -> OpenFlags
pub fn all() -> OpenFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_ulong
pub fn bits(&self) -> c_ulongReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_ulong) -> Option<OpenFlags>
pub fn from_bits(bits: c_ulong) -> Option<OpenFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_ulong) -> OpenFlags
pub fn from_bits_truncate(bits: c_ulong) -> OpenFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: OpenFlags) -> bool
pub fn intersects(&self, other: OpenFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: OpenFlags) -> bool
pub fn contains(&self, other: OpenFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: OpenFlags)
pub fn insert(&mut self, other: OpenFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: OpenFlags)
pub fn remove(&mut self, other: OpenFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: OpenFlags)
pub fn toggle(&mut self, other: OpenFlags)Toggles the specified flags in-place.