Struct ssh2::ReadWindow [−][src]
Description of the read window as returned by Channel::read_window
Fields
remaining: u32
The number of bytes which the remote end may send without overflowing the window limit.
available: u32
The number of bytes actually available to be read.
window_size_initial: u32
The window_size_initial as defined by the channel open request