Struct ssh2::RenameFlags [−]
pub struct RenameFlags { /* fields omitted */ }Options to Sftp::rename
Methods
impl RenameFlags
impl RenameFlagspub fn empty() -> RenameFlags
pub fn empty() -> RenameFlagsReturns an empty set of flags.
pub fn all() -> RenameFlags
pub fn all() -> RenameFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_long
pub fn bits(&self) -> c_longReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_long) -> Option<RenameFlags>
pub fn from_bits(bits: c_long) -> Option<RenameFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_long) -> RenameFlags
pub fn from_bits_truncate(bits: c_long) -> RenameFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RenameFlags) -> bool
pub fn intersects(&self, other: RenameFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RenameFlags) -> bool
pub fn contains(&self, other: RenameFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RenameFlags)
pub fn insert(&mut self, other: RenameFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RenameFlags)
pub fn remove(&mut self, other: RenameFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RenameFlags)
pub fn toggle(&mut self, other: RenameFlags)Toggles the specified flags in-place.