Struct ssh2::ScpFileStat [−][src]
pub struct ScpFileStat { /* fields omitted */ }Metadata returned about a remote file when received via scp.
Methods
impl ScpFileStat[src]
impl ScpFileStatpub fn size(&self) -> u64[src]
pub fn size(&self) -> u64Returns the size of the remote file.
pub fn mode(&self) -> i32[src]
pub fn mode(&self) -> i32Returns the listed mode of the remote file.
pub fn is_dir(&self) -> bool[src]
pub fn is_dir(&self) -> boolReturns whether the remote file is a directory.
pub fn is_file(&self) -> bool[src]
pub fn is_file(&self) -> boolReturns whether the remote file is a regular file.