Struct ssh2::Stream [] [src]

pub struct Stream<'channel, 'sess: 'channel> {
    // some fields omitted
}

A channel can have a number of streams, each identified by an id, each of which implements the Read and Write traits.