Struct ssh2::WriteWindow [−][src]
Description of the write window as returned by Channel::write_window
Fields
remaining: u32
The number of bytes which may be safely written on the channel without blocking.
window_size_initial: u32
The window_size_initial as defined by the channel open request