Agent

Struct Agent 

pub struct Agent { /* private fields */ }
A structure representing a connection to an SSH agent.

Agents can be used to authenticate a session.

Implementations

Source

impl Agent

pub fn connect(&mut self) -> Result<(), Error>

Connect to an ssh-agent running on the system.

pub fn disconnect(&mut self) -> Result<(), Error>

Close a connection to an ssh-agent.

pub fn list_identities(&mut self) -> Result<(), Error>

Request an ssh-agent to list of public keys, and stores them in the internal collection of the handle.

Call identities to get the public keys.

pub fn identities(&self) -> Result<Vec<PublicKey>, Error>

Get list of the identities of this agent.

pub fn userauth( &self, username: &str, identity: &PublicKey, ) -> Result<(), Error>

Attempt public key authentication with the help of ssh-agent.

pub fn set_identity_path(&mut self, path: &Path) -> Result<(), Error>

Set a custom agent socket path to connect to.

pub fn identity_path(&self) -> Option<PathBuf>

Get the custom agent socket path, if set.