Struct ssh2::ExitSignal [−][src]
pub struct ExitSignal {
pub exit_signal: Option<String>,
pub error_message: Option<String>,
pub lang_tag: Option<String>,
}Expand description
Data received from when a program exits with a signal.
Fields
exit_signal: Option<String>The exit signal received, if the program did not exit cleanly. Does not contain a SIG prefix
error_message: Option<String>Error message provided by the remote server (if any)
lang_tag: Option<String>Language tag provided by the remote server (if any)