Struct ssh2::FileStat
[−]
[src]
pub struct FileStat {
pub size: Option<u64>,
pub uid: Option<u32>,
pub gid: Option<u32>,
pub perm: Option<u32>,
pub atime: Option<u64>,
pub mtime: Option<u64>,
}Metadata information about a remote file.
Fields are not necessarily all provided
Fields
size: Option<u64>
File size, in bytes of the file.
uid: Option<u32>
Owner ID of the file
gid: Option<u32>
Owning group of the file
perm: Option<u32>
Permissions (mode) of the file
atime: Option<u64>
Last access time of the file
mtime: Option<u64>
Last modification time of the file
Methods
impl FileStat[src]
fn file_type(&self) -> FileType
Returns the file type for this filestat.
fn is_dir(&self) -> bool
Returns whether this metadata is for a directory.
fn is_file(&self) -> bool
Returns whether this metadata is for a regular file.
fn from_raw(raw: &LIBSSH2_SFTP_ATTRIBUTES) -> FileStat
Creates a new instance of a stat from a raw instance.
fn raw(&self) -> LIBSSH2_SFTP_ATTRIBUTES
Convert this stat structure to its raw representation.