Struct ssh2::Host [−][src]
pub struct Host<'kh> { /* fields omitted */ }Structure representing a known host as part of a KnownHosts structure.
Methods
impl<'kh> Host<'kh>[src]
impl<'kh> Host<'kh>pub fn name(&self) -> Option<&str>[src]
pub fn name(&self) -> Option<&str>This is None if no plain text host name exists.
pub fn key(&self) -> &str[src]
pub fn key(&self) -> &strReturns the key in base64/printable format