Struct ssh2::Prompt [−][src]
A prompt/challenge returned as part of keyboard-interactive authentication
Fields
text: Cow<'a, str>The label to show when prompting the user
echo: boolIf true, the response that the user inputs should be displayed as they type. If false then treat it as a password entry and do not display what is typed in response to this prompt.