Struct ssh2::ScpFileStat [] [src]

pub struct ScpFileStat {
    // some fields omitted
}

Metadata returned about a remote file when received via scp.

Methods

impl ScpFileStat
[src]

fn size(&self) -> u64

Returns the size of the remote file.

fn mode(&self) -> i32

Returns the listed mode of the remote file.

fn is_dir(&self) -> bool

Returns whether the remote file is a directory.

fn is_file(&self) -> bool

Returns whether the remote file is a regular file.